package checkers.interned;

import checkers.basetype.*;
import checkers.metaquals.TypeQualifiers;
import checkers.quals.Interned;
import checkers.source.*;

import javax.annotation.processing.*;
import javax.lang.model.*;

/**
 * A typechecker plug-in for the {@link checkers.quals.Interned} qualifier that
 * finds (and verifies the absence of) equality-testing and interning errors.
 *
 * <p>
 *
 * The {@link checkers.quals.Interned} annotation indicates that a variable
 * refers to the canonical instance of an object, meaning that it is safe to
 * compare that object using the "==" operator. This plugin suggests using "=="
 * instead of ".equals" where possible, and warns whenever "==" is used in cases
 * where one or both operands are not {@link checkers.quals.Interned}.
 *
 * @manual #interned Interned checker
 */
@SupportedSourceVersion(SourceVersion.RELEASE_7)
@SupportedLintOptions({"dotequals", "flow"})
@SuppressWarningsKey("interned")
@TypeQualifiers({ Interned.class })
public final class InternedChecker extends BaseTypeChecker { }
